import { Component, OnInit } from '@angular/core';
import { MatDialog } from '@angular/material/dialog';
import { HttpClient } from '@angular/common/http';
import { CreateImageComponent } from './create-image/create-image/create-image.component';
import { EditImageComponent } from './edit-image/edit-image/edit-image.component';

@Component({
  selector: 'app-images',
  templateUrl: './images.component.html',
  styleUrls: ['./images.component.css']
})
export class ImagesComponent implements OnInit {
  images: { downloadUrl: string; name: string; uuid: string }[] = [];

  private apiUrl = 'http://127.0.0.1:8080/og-lives';

  constructor(public dialog: MatDialog, private http: HttpClient) {}

  ngOnInit(): void {
    this.loadImages();
  }

  loadImages(): void {
    this.http.get<any>(`${this.apiUrl}?page=1&itemsPerPage=30`).subscribe({
      next: (response) => {
        this.images = response['hydra:member'].map((item: any) => ({
          downloadUrl: item.downloadUrl,
          name: item.name,
          uuid: item.uuid
        }));
      },
      error: (error) => {
        console.error('Error al cargar las imágenes:', error);
      }
    });
  }

  addImage(): void {
    const dialogRef = this.dialog.open(CreateImageComponent, {
      width: '400px'
    });

    dialogRef.afterClosed().subscribe(result => {
      console.log('The dialog was closed');
      this.loadImages(); // Opcional: recargar imágenes después de añadir una nueva
    });
  }

  showInfo(image: any): void {
    // Implementar lógica para mostrar información
    console.log('Mostrar info:', image);
  }

  toggleStatus(image: any): void {
    // Implementar lógica para montar/desmontar
    console.log('Montar/Desmontar:', image);
  }

  deleteImage(uuid: string): void {
    this.http.delete(`${this.apiUrl}/${uuid}`).subscribe({
      next: () => {
        console.log('Imagen eliminada');
        this.loadImages(); // Recargar imágenes después de eliminar
      },
      error: (error) => {
        console.error('Error al eliminar la imagen:', error);
      }
    });
  }

  editImage(image: any): void {
    const dialogRef = this.dialog.open(EditImageComponent, {
      width: '300px',
      data: image // Pasa los datos de la imagen a editar
    });
  
    dialogRef.afterClosed().subscribe(result => {
      if (result) {
        // Opcional: Actualiza la lista de imágenes o realiza otras acciones necesarias
        this.loadImages();
      }
    });
  }
  
}
